gpe.univ package
================

Submodules
----------

gpe.univ.fns module
-------------------

.. automodule:: gpe.univ.fns
   :members:
   :undoc-members:
   :show-inheritance:

gpe.univ.grid module
--------------------

.. automodule:: gpe.univ.grid
   :members:
   :undoc-members:
   :show-inheritance:

gpe.univ.my\_fft module
-----------------------

.. automodule:: gpe.univ.my_fft
   :members:
   :undoc-members:
   :show-inheritance:

gpe.univ.params module
----------------------

.. automodule:: gpe.univ.params
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: gpe.univ
   :members:
   :undoc-members:
   :show-inheritance:
